# HAL

![Versions](https://img.shields.io/badge/python->3.9-blue)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Documentation Status](https://readthedocs.org/projects/sdss-hal/badge/?version=latest)](https://sdss-hal.readthedocs.io/en/latest/?badge=latest)
[![Test](https://github.com/sdss/hal/actions/workflows/test.yml/badge.svg)](https://github.com/sdss/hal/actions/workflows/test.yml)
[![codecov](https://codecov.io/gh/sdss/hal/branch/main/graph/badge.svg)](https://codecov.io/gh/sdss/hal)

High-level observing actor for SDSS-V (replaces SOP)

## Installation

You should be able to install `HAL` by doing

```console
pip install sdss-hal
```

To build from source, use

```console
git clone git@github.com:sdss/hal
cd hal
pip install .
```
